<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Defaŭlte, ĉiujn ligilojn al bildoj (kun atributo „type“, kiu difinas la bildan MIME-tipon) kaj la ligilojn kun la klaso <code>.mediabox</code> pliriĉigas la plurmedia skatolo.
 
	Eblas agordi ĉiun ligilon unuope per pliaj klasoj :
	
-* <code>boxIframe</code>, por ke la ligilo malfermiĝu en IFRAME-skatolo ;

-* <code>boxWidth-350px</code> por skatolo largâ je 350px (px = bilderoj) ;

-* <code>boxHeight-90pc</code> por skatolo alta je 90%.

	Agordilaro ebligas vin modifi plurajn aspektojn laŭvole.
	
	Tiu kromprogramo funkcias ĉe la skeletoj, kiuj uzas la markon <code>#INSERT_HEAD</code>.',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Plurmedia skatolo',
];
